@@ -36,6 +36,7 @@
 #include "mutt_crypt.h"
 #include "mutt_idna.h"
 #include "buffy.h"
+#include "send.h"
 
 #ifdef USE_AUTOCRYPT
 #include "autocrypt.h"
@@ -1302,7 +1303,7 @@ void mutt_update_encoding (BODY *a)
 
 BODY *mutt_make_message_attach (CONTEXT *ctx, HEADER *hdr, int attach_msg)
 {
-  char buffer[LONG_STRING];
+  BUFFER *buffer = NULL;
   BODY *body;
   FILE *fp;
   int cmflags, chflags;
@@ -1318,19 +1319,25 @@ BODY *mutt_make_message_attach (CONTEXT *ctx, HEADER *hdr, int attach_msg)
     }
   }
 
-  mutt_mktemp (buffer, sizeof (buffer));
-  if ((fp = safe_fopen (buffer, "w+")) == NULL)
+  buffer = mutt_buffer_pool_get ();
+  mutt_buffer_mktemp (buffer);
+  if ((fp = safe_fopen (mutt_b2s (buffer), "w+")) == NULL)
+  {
+    mutt_buffer_pool_release (&buffer);
     return NULL;
+  }
 
   body = mutt_new_body ();
   body->type = TYPEMESSAGE;
   body->subtype = safe_strdup ("rfc822");
-  body->filename = safe_strdup (buffer);
+  body->filename = safe_strdup (mutt_b2s (buffer));
   body->unlink = 1;
   body->use_disp = 0;
   body->disposition = DISPINLINE;
   body->noconv = 1;
 
+  mutt_buffer_pool_release (&buffer);
+
   mutt_parse_mime_message (ctx, hdr);
 
   chflags = CH_XMIT;
@@ -2974,8 +2981,9 @@ static void set_noconv_flags (BODY *b, short flag)
   }
 }
 
-int mutt_write_fcc (const char *path, HEADER *hdr, const char *msgid, int post, const char *fcc)
+int mutt_write_fcc (const char *path, SEND_CONTEXT *sctx, const char *msgid, int post, const char *fcc)
 {
+  HEADER *hdr;
   CONTEXT f;
   MESSAGE *msg;
   BUFFER *tempfile = NULL;
@@ -2985,6 +2993,8 @@ int mutt_write_fcc (const char *path, HEADER *hdr, const char *msgid, int post,
   char buf[SHORT_STRING];
   int onm_flags;
 
+  hdr = sctx->msg;
+
   if (post)
     set_noconv_flags (hdr->content, 1);
 
@@ -3067,8 +3077,8 @@ int mutt_write_fcc (const char *path, HEADER *hdr, const char *msgid, int post,
     if (hdr->security & SIGN)
     {
       fputc ('S', msg->fp);
-      if (PgpSignAs)
-        fprintf (msg->fp, "<%s>", PgpSignAs);
+      if (sctx->pgp_sign_as)
+        fprintf (msg->fp, "<%s>", sctx->pgp_sign_as);
     }
     if (hdr->security & INLINE)
       fputc ('I', msg->fp);
@@ -3089,16 +3099,16 @@ int mutt_write_fcc (const char *path, HEADER *hdr, const char *msgid, int post,
     if (hdr->security & ENCRYPT)
     {
       fputc ('E', msg->fp);
-      if (SmimeCryptAlg)
-        fprintf (msg->fp, "C<%s>", SmimeCryptAlg);
+      if (sctx->smime_crypt_alg)
+        fprintf (msg->fp, "C<%s>", sctx->smime_crypt_alg);
     }
     if (hdr->security & OPPENCRYPT)
       fputc ('O', msg->fp);
     if (hdr->security & SIGN)
     {
       fputc ('S', msg->fp);
-      if (SmimeSignAs)
-        fprintf (msg->fp, "<%s>", SmimeSignAs);
+      if (sctx->smime_sign_as)
+        fprintf (msg->fp, "<%s>", sctx->smime_sign_as);
     }
     if (hdr->security & INLINE)
       fputc ('I', msg->fp);
